/*
 *    dtToPd.H --- Convert Dokwer-Thistlethwaite to Planar-Diagram code.
 *                      Part of Foamho, a sl3-homology calculator.
 *
 * Copyright (C) 2012 Lukas Lewark <lewark@math.jussieu.fr>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 *
 */

typedef struct UnsignedIntList_ {
    unsigned data;
    struct UnsignedIntList_ *next;
} UnsignedIntList;

/* Given a diagram in PD-notation (parameter c points to an array of size
 * 2*nbCrossings, and input_signs is a vector of size nbCrossings), dtSigns
 * recursively computes the signs of all crossings, and writes them to
 * output_signs. It does not work for links (yet). See the function dtToVUiv
 * in parser.C for an example how to call dtSigns.
 */
bool dtSigns(UnsignedIntList *position, unsigned *region, unsigned segment,
        unsigned movingIn, unsigned movingOut, unsigned currentRegion,
        unsigned newRegion, unsigned const *order,
        std::vector<bool> const &input_signs, std::vector<bool> &output_signs,
        unsigned nbCrossings, unsigned *c,
        unsigned const *linkComponents, bool changeRegion);

UnsignedIntList* newUnsignedIntList(unsigned newData);
